lru

package
v0.0.0-...-0ec8b3e Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 29, 2022 License: Apache-2.0 Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewLockedLRU

func NewLockedLRU(size int, name string, openStat bool,
	emitCounter func(name string, value interface{}, prefix string, tagkv map[string]string)) *lockedLRU

NewLocked constructs a new Cache of the given size that is safe for concurrent use. It will panic if size is not a positive integer.

Types

This section is empty.

Jump to