Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewLockedLRU ¶
func NewLockedLRU(size int, name string, openStat bool, emitCounter func(name string, value interface{}, prefix string, tagkv map[string]string)) *lockedLRU
NewLocked constructs a new Cache of the given size that is safe for concurrent use. It will panic if size is not a positive integer.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.